<?php
/**
 * @file
 * Ensemble Video Chooser callback include.
 */

/**
 * Launch callback from ensemble_video_chooser_menu().
 */
function ensemble_video_chooser_launch() {
  global $user, $base_url;

  $url = variable_get('ensemble_video_chooser_launch_url', '');
  $consumer_key = variable_get('ensemble_video_chooser_consumer_key', '');
  $shared_secret = variable_get('ensemble_video_chooser_shared_secret', '');
  $additional_params = variable_get('ensemble_video_chooser_custom_params', '');

  $consumer = new DrupalOAuthConsumer($consumer_key, $shared_secret);
  $request = DrupalOAuthRequest::from_consumer_and_token($consumer, FALSE, 'POST', $url);

  // Add our LTI params.
  $request->set_parameter('oauth_callback', 'about:blank');
  $request->set_parameter('lis_person_contact_email_primary', $user->mail);
  $request->set_parameter('lti_message_type', 'basic-lti-launch-request');
  $request->set_parameter('lti_version', 'LTI-1p0');
  $request->set_parameter('resource_link_id', 'TODO');
  $request->set_parameter('tool_consumer_info_product_family_code', 'drupal');
  $request->set_parameter('user_id', $user->uid);
  $request->set_parameter('launch_presentation_return_url', $base_url . '/evchooser/return');
  $request->set_parameter('custom_drupal_user_login_id', $user->name);
  $params = explode("\n", $additional_params);
  foreach ($params as $param) {
    $param = trim($param);
    if ($param === '') {
      continue;
    }
    $parts = explode('=', $param);
    if (count($parts) !== 2) {
      continue;
    }
    $parts[0] = trim($parts[0]);
    $parts[1] = trim($parts[1]);
    $request->set_parameter($parts[0], $parts[1]);
  }

  $request->sign_request(new OAuthSignatureMethod_HMAC('SHA1'), $consumer, FALSE);

  $variables = array();
  $variables['page_title'] = t('Ensemble Video Chooser Launch');
  $variables['scripts'] = drupal_get_js();
  $variables['launch_url'] = $url;
  $variables['launch_data'] = $request->get_parameters();

  return theme('evchooser_launch', $variables);
}

/**
 * Return callback from ensemble_video_chooser_menu().
 */
function ensemble_video_chooser_return() {
  $variables = array();
  $variables['page_title'] = t('Ensemble Video Chooser Return');
  $variables['scripts'] = drupal_get_js();

  return theme('evchooser_return', $variables);
}

/**
 * Custom delivery callback for chooser paths.
 *
 * @see drupal_deliver_html_page()
 */
function ensemble_video_chooser_delivery_callback($page_callback_result) {
  // If result is a status code rather than content, let Drupal handle it.
  if (is_int($page_callback_result)) {
    return drupal_deliver_html_page($page_callback_result);
  }

  if (isset($page_callback_result) && is_null(drupal_get_http_header('Content-Type'))) {
    drupal_add_http_header('Content-Type', 'text/html; charset=utf-8');
  }

  global $language;
  drupal_add_http_header('Content-Language', $language->language);

  if (isset($page_callback_result)) {
    print render($page_callback_result);
  }

  drupal_page_footer();
}
